# General Modeling Guidelines
### On this page
  * [General Guidelines](https://help.sap.com/docs/leanix/ea/general-modeling-guidelines?version=CLOUD#general-guidelines)
  * [Example: Modeling SAP LeanIX as an Application](https://help.sap.com/docs/leanix/ea/general-modeling-guidelines?version=CLOUD#example:-modeling-sap-leanix-as-an-application)
  * [Related Information](https://help.sap.com/docs/leanix/ea/general-modeling-guidelines?version=CLOUD#related-information)


Learn how the SAP LeanIX meta model works and how to interpret key concepts like fact sheet attributes, tags, hierarchies, parent-child relations, and others.
This page provides an end-to-end example of how to use the predefined meta model in SAP LeanIX. It will help you understand how the meta model works and how to interpret key concepts like [fact sheet](https://help.sap.com/docs/leanix/ea/fact-sheets?locale=en-US&state=PRODUCTION&version=CLOUD "Fact sheets in SAP LeanIX are used to record essential and comprehensive details about each architectural object, such as applications, business capabilities, IT components, etc. Learn about their structure, types, and subtypes.") attributes, [tags](https://help.sap.com/docs/leanix/ea/tags?locale=en-US&state=PRODUCTION&version=CLOUD "Tags are labels used to classify and categorize fact sheets, making it easy to filter, organize, and analyze data. Learn how to assign and manage tags, understand when and when not to use them, as well as leverage them for filtering and reporting."), hierarchies, parent-child relations, and others.
For detailed guidance on modeling each fact sheet type, refer to [Fact Sheet Modeling Guidelines](https://help.sap.com/docs/leanix/ea/fact-sheet-modeling-guidelines?locale=en-US&state=PRODUCTION&version=CLOUD).
